%define qemu_user  root
%define qemu_group root

Name:          libvirt
Version:       9.8.0
Release:       2mamba
Summary:       Virtualization API
Group:         Development/Libraries
Vendor:        openmamba
Distribution:  openmamba
Packager:      Silvan Calarco <silvan.calarco@mambasoft.it>
URL:           https://libvirt.org
Source0:       http://libvirt.org/sources/libvirt-%{version}.tar.xz
Source1:       libvirt.sysconfig
Source2:       libvirt.initscript
Patch0:        libvirt-1.0.5-tirpc.patch
License:       LGPL
## AUTOBUILDREQ-BEGIN
BuildRequires: glibc-devel
BuildRequires: ldconfig
BuildRequires: libacl-devel
BuildRequires: libaudit-devel
BuildRequires: libblkid-devel
BuildRequires: libcap-ng-devel
BuildRequires: libcurl-devel
BuildRequires: libdevmapper-devel
BuildRequires: libfuse-devel
BuildRequires: libgcc
BuildRequires: libglib-devel
BuildRequires: libgnutls-devel
BuildRequires: libnl-devel
BuildRequires: libnuma-devel
BuildRequires: libparted-devel
BuildRequires: libpcap-devel
BuildRequires: libpciaccess-devel
BuildRequires: libreadline-devel
BuildRequires: libsasl2-devel
BuildRequires: libselinux-devel
BuildRequires: libssh-devel
BuildRequires: libssh2-devel
BuildRequires: libtirpc-devel
BuildRequires: libudev-devel
BuildRequires: libwireshark-devel
%ifnarch arm aarch64
BuildRequires: libxen-devel
%endif
BuildRequires: libxml2-devel
BuildRequires: libyajl-devel
## AUTOBUILDREQ-END
BuildRequires: libwireshark-devel >= 0:4.0.1-1mamba
%ifarch %{ix86} x86_64
BuildRequires: libxen-devel >= 4.17.2-1mamba
BuildRequires: libsmbios-devel
%endif
BuildRequires: libyajl-devel
BuildRequires: libpcap-devel >= 1.2
BuildRequires: systemtap-sdt-devel
Requires:      dnsmasq
Requires:      ebtables
Requires:      netcat-openbsd
Provides:      libvirt-client
Obsoletes:     libvirt-client < 7.3.0

%description
Libvirt is a C toolkit to interact with the virtualization capabilities of recent versions of Linux (and other OSes).

%package -n python-%{name}
Group:         Development/Libraries
Summary:       Python bindings for the libvirt library
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description -n python-%{name}
The libvirt-python package contains a module that permits applications written in the Python programming language to use the interface supplied by the libvirt library to use the virtualization capabilities of recent versions of Linux (and other OSes).

%package devel
Group:         Development/Libraries
Summary:       Static libraries and headers for %{name}
Requires:      %{name} = %{?epoch:%epoch:}%{version}-%{release}

%description devel
Libvirt is a C toolkit to interact with the virtualization capabilities of recent versions of Linux (and other OSes).
This package contains static libraries and header files needed for development.

%debug_package

%prep
%setup -q
#-D -T
#% patch0 -p1

%build
#:<< _EOF
%meson \
   -Dinit_script=systemd \
   -Dqemu_user=%{qemu_user} \
   -Dqemu_group=%{qemu_group}
   
#CPPFLAGS="%{optflags} -I%{_inclduedir}/tirpc" \
#CFLAGS="%{optflags} -I%{_includedir}/tirpc" \
#% configure \
#%ifnarch arm
#   --with-xen \
#%endif
#  --with-systemd-daemon \
#   --with-init-script=systemd \
#   --with-qemu-user=%{qemu_user} \
#   --with-qemu-group=%{qemu_group} \
#   --without-wireshark-dissector

#   --with-remote-pid-file=%{_localstatedir}/run/libvirtd.pid \

%meson_build

%install
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"
%meson_install

mv %{buildroot}%{_prefix}%{_libdir}/wireshark %{buildroot}%{_libdir}/

install -D -m644 %{S:1} %{buildroot}%{_sysconfdir}/sysconfig/libvirtd 

install -d %{buildroot}%{_localstatedir}/log/libvirt/{lxc,uml,qemu}

install -d %{buildroot}%{_sysconfdir}/polkit-1/localauthority/50-local.d

cat > %{buildroot}%{_sysconfdir}/polkit-1/localauthority/50-local.d/50-org.libvirt.unix.manage.pkla << _EOF
[Allow group libvirt management permissions]
Identity=unix-group:sysadmin
Action=org.libvirt.unix.manage
ResultAny=yes
ResultInactive=yes
ResultActive=yes
_EOF

%find_lang %{name}

rm -fr %{buildroot}%{_datadir}/doc/libvirt-%{version}
rm -fr %{buildroot}%{_datadir}/doc/libvirt-python-%{version}

rm -f %{buildroot}%{_libdir}/*.a

%clean
[ "%{buildroot}" != / ] && rm -rf "%{buildroot}"

%post
/sbin/ldconfig
%systemd_post libvirtd
:

%preun
%systemd_preun libvirtd
:

%postun
/sbin/ldconfig
%systemd_postun libvirtd
:

%files -f %{name}.lang
%defattr(-,root,root)
%config(noreplace) %{_sysconfdir}/libvirt/libvirt.conf
%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%dir %{_sysconfdir}/libvirt
%dir %{_sysconfdir}/libvirt/qemu
%dir %{_sysconfdir}/libvirt/qemu/networks
#%config(noreplace) %{_sysconfdir}/sasl2/libvirt.conf
%ifnarch arm aarch64
%config(noreplace) %{_sysconfdir}/libvirt/libxl-lockd.conf
%config(noreplace) %{_sysconfdir}/libvirt/libxl.conf
%endif
#%{_sysconfdir}/sysconfig/libvirt-guests
%config(noreplace) %{_sysconfdir}/libvirt/qemu/networks/default.xml
%dir %{_sysconfdir}/libvirt/qemu/networks/autostart
%config(noreplace) %{_sysconfdir}/libvirt/qemu/networks/autostart/default.xml
%{_sysconfdir}/libvirt/nwfilter
%{_sysconfdir}/polkit-1/localauthority/50-local.d/50-org.libvirt.unix.manage.pkla
%{_sysconfdir}/apparmor.d/abstractions/libvirt-*
%dir %{_sysconfdir}/apparmor.d/libvirt
%{_sysconfdir}/apparmor.d/libvirt/TEMPLATE.*
#%{_sysconfdir}/apparmor.d/local/usr.lib.libvirt.virt-aa-helper
%{_sysconfdir}/apparmor.d/usr.lib.libvirt.virt-aa-helper
%{_sysconfdir}/apparmor.d/usr.sbin.libvirtd
%{_sysconfdir}/apparmor.d/usr.sbin.virtqemud
%{_sysconfdir}/apparmor.d/usr.sbin.virtxend
%config(noreplace) %{_sysconfdir}/sysconfig/libvirtd
%config(noreplace) %{_sysconfdir}/libvirt/libvirt-admin.conf
%config(noreplace) %{_sysconfdir}/libvirt/libvirtd.conf
%config(noreplace) %{_sysconfdir}/libvirt/lxc.conf
%config(noreplace) %{_sysconfdir}/libvirt/qemu.conf
%config(noreplace) %{_sysconfdir}/libvirt/qemu-lockd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virt-login-shell.conf
%ifnarch %{ix86} arm
%config(noreplace) %{_sysconfdir}/libvirt/virtchd.conf
%endif
%config(noreplace) %{_sysconfdir}/libvirt/virtlockd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlogd.conf
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd
%config(noreplace) %{_sysconfdir}/logrotate.d/libvirtd.*
%config(noreplace) %{_sysconfdir}/libvirt/virtinterfaced.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtlxcd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtnetworkd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtnodedevd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtnwfilterd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtproxyd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtqemud.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtsecretd.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtstoraged.conf
%config(noreplace) %{_sysconfdir}/libvirt/virtvboxd.conf
%ifarch x86_64 %{ix86}
%config(noreplace) %{_sysconfdir}/libvirt/virtxend.conf
%endif
%{_bindir}/virt-*
%{_bindir}/virsh
%{_sbindir}/libvirtd
%{_sbindir}/virt*
%{_libdir}/lib*.so.*
%dir %{_libdir}/libvirt
%dir %{_libdir}/libvirt/connection-driver
%{_libdir}/libvirt/connection-driver/libvirt_driver_*.so
%{_libdir}/libvirt/storage-backend/libvirt_storage_backend_*.so
%{_libdir}/libvirt/storage-file/libvirt_storage_file_fs.so
%{_libdir}/wireshark/plugins/*/epan/libvirt.so
%dir %{_libdir}/libvirt/lock-driver
%{_libdir}/libvirt/lock-driver/lockd.so
%{_libexecdir}/libvirt_*
%{_libexecdir}/libvirt-guests.sh
%{_libexecdir}/virt-aa-helper
%{_libexecdir}/virt-login-shell-helper
%{_unitdir}/libvirtd.service
%{_unitdir}/libvirtd-admin.socket
%{_unitdir}/libvirt-guests.service
%{_unitdir}/libvirtd-ro.socket
%{_unitdir}/libvirtd-tcp.socket
%{_unitdir}/libvirtd-tls.socket
%{_unitdir}/libvirtd.socket
%{_unitdir}/virtlockd.service
%{_unitdir}/virtlockd.socket
%{_unitdir}/virtlogd.service
%{_unitdir}/virtlogd.socket
%{_unitdir}/virt-guest-shutdown.target
%{_unitdir}/virtinterfaced-admin.socket
%{_unitdir}/virtinterfaced-ro.socket
%{_unitdir}/virtinterfaced.service
%{_unitdir}/virtinterfaced.socket
%{_unitdir}/virtlockd-admin.socket
%{_unitdir}/virtlogd-admin.socket
%{_unitdir}/virtlxcd-admin.socket
%{_unitdir}/virtlxcd-ro.socket
%{_unitdir}/virtlxcd.service
%{_unitdir}/virtlxcd.socket
%{_unitdir}/virtnetworkd-admin.socket
%{_unitdir}/virtnetworkd-ro.socket
%{_unitdir}/virtnetworkd.service
%{_unitdir}/virtnetworkd.socket
%{_unitdir}/virtnodedevd-admin.socket
%{_unitdir}/virtnodedevd-ro.socket
%{_unitdir}/virtnodedevd.service
%{_unitdir}/virtnodedevd.socket
%{_unitdir}/virtnwfilterd-admin.socket
%{_unitdir}/virtnwfilterd-ro.socket
%{_unitdir}/virtnwfilterd.service
%{_unitdir}/virtnwfilterd.socket
%{_unitdir}/virtproxyd-admin.socket
%{_unitdir}/virtproxyd-ro.socket
%{_unitdir}/virtproxyd-tcp.socket
%{_unitdir}/virtproxyd-tls.socket
%{_unitdir}/virtproxyd.service
%{_unitdir}/virtproxyd.socket
%{_unitdir}/virtqemud-admin.socket
%{_unitdir}/virtqemud-ro.socket
%{_unitdir}/virtqemud.service
%{_unitdir}/virtqemud.socket
%{_unitdir}/virtsecretd-admin.socket
%{_unitdir}/virtsecretd-ro.socket
%{_unitdir}/virtsecretd.service
%{_unitdir}/virtsecretd.socket
%{_unitdir}/virtstoraged-admin.socket
%{_unitdir}/virtstoraged-ro.socket
%{_unitdir}/virtstoraged.service
%{_unitdir}/virtstoraged.socket
%{_unitdir}/virtvboxd-admin.socket
%{_unitdir}/virtvboxd-ro.socket
%{_unitdir}/virtvboxd.service
%{_unitdir}/virtvboxd.socket
%ifnarch %{ix86} arm
%{_unitdir}/virtchd-admin.socket
%{_unitdir}/virtchd-ro.socket
%{_unitdir}/virtchd.service
%{_unitdir}/virtchd.socket
%endif
%ifarch x86_64 %{ix86}
%{_unitdir}/virtxend-admin.socket
%{_unitdir}/virtxend-ro.socket
%{_unitdir}/virtxend.service
%{_unitdir}/virtxend.socket
%endif
%{_prefix}/lib/sysctl.d/*.conf
%{_prefix}/lib/firewalld/*
%{_datadir}/polkit-1/actions/org.libvirt.unix.policy
%dir %{_datadir}/libvirt
%dir %{_datadir}/libvirt/cpu_map
%{_datadir}/libvirt/cpu_map/*.xml
%{_datadir}/libvirt/api/libvirt-admin-api.xml
%{_datadir}/libvirt/schemas/*.rng
#%{_datadir}/bash-completion/completions/vsh
%dir %{_datadir}/libvirt/api
%{_datadir}/libvirt/api/libvirt-api.xml
%{_datadir}/libvirt/api/libvirt-lxc-api.xml
%{_datadir}/libvirt/test-screenshot.png
%{_datadir}/augeas/lenses/*.aug
%{_datadir}/augeas/lenses/tests/test_*.aug
%{_datadir}/bash-completion/completions/virsh
%{_datadir}/bash-completion/completions/virt-admin
%{_datadir}/polkit-1/actions/org.libvirt.api.policy
%{_datadir}/polkit-1/rules.d/50-libvirt.rules
%{_datadir}/systemtap/tapset/libvirt_*.stp
%dir %{_localstatedir}/log/libvirt
%dir %{_localstatedir}/log/libvirt/lxc
%dir %{_localstatedir}/log/libvirt/uml
%dir %{_localstatedir}/log/libvirt/qemu
%{_mandir}/man1/virt-*.1*
%{_mandir}/man1/virsh.*
%{_mandir}/man8/libvirtd.8*
%{_mandir}/man8/virt*.8*
%{_mandir}/man8/libvirt-guests.8*
%{_datadir}/libvirt/api/libvirt-qemu-api.xml
%doc COPYING.LESSER

%files devel
%defattr(-,root,root)
%dir %{_includedir}/libvirt
%{_includedir}/libvirt/*.h
%{_libdir}/lib*.so
%dir %{_docdir}/libvirt
%dir %{_docdir}/libvirt/examples
%{_docdir}/libvirt/examples/*
%dir %{_docdir}/libvirt/html
%{_docdir}/libvirt/html/*
%{_libdir}/pkgconfig/libvirt*.pc
%{_mandir}/man7/virkeycode-*.7*
%{_mandir}/man7/virkeyname-*.7*

%changelog
* Tue Oct 10 2023 Automatic Build System <autodist@mambasoft.it> 9.8.0-2mamba
- rebuilt by autoport with build requirements: libxen-devel>=4.17.2-1mamba

* Mon Oct 02 2023 Automatic Build System <autodist@mambasoft.it> 9.8.0-1mamba
- automatic version update by autodist

* Sat Sep 02 2023 Automatic Build System <autodist@mambasoft.it> 9.7.0-1mamba
- automatic version update by autodist

* Fri Aug 04 2023 Automatic Build System <autodist@mambasoft.it> 9.6.0-1mamba
- automatic version update by autodist

* Mon Jul 03 2023 Automatic Build System <autodist@mambasoft.it> 9.5.0-1mamba
- automatic version update by autodist

* Thu Jun 01 2023 Automatic Build System <autodist@mambasoft.it> 9.4.0-1mamba
- automatic version update by autodist

* Tue May 02 2023 Automatic Build System <autodist@mambasoft.it> 9.3.0-1mamba
- automatic version update by autodist

* Sat Apr 01 2023 Automatic Build System <autodist@mambasoft.it> 9.2.0-1mamba
- automatic version update by autodist

* Thu Mar 02 2023 Automatic Build System <autodist@mambasoft.it> 9.1.0-1mamba
- automatic version update by autodist

* Tue Jan 17 2023 Automatic Build System <autodist@mambasoft.it> 9.0.0-1mamba
- automatic version update by autodist

* Wed Jan 11 2023 Sdk Build System <sdk@mambasoft.it> 8.10.0-2mamba
- rebuilt by autoport with build requirements: libwireshark-devel>=0:4.0.1-1mamba

* Sat Dec 03 2022 Automatic Build System <autodist@mambasoft.it> 8.10.0-1mamba
- automatic version update by autodist

* Wed Nov 02 2022 Automatic Build System <autodist@mambasoft.it> 8.9.0-1mamba
- automatic version update by autodist

* Fri Oct 07 2022 Automatic Build System <autodist@mambasoft.it> 8.8.0-1mamba
- automatic version update by autodist

* Fri Sep 02 2022 Automatic Build System <autodist@mambasoft.it> 8.7.0-1mamba
- automatic version update by autodist

* Mon Aug 01 2022 Automatic Build System <autodist@mambasoft.it> 8.6.0-1mamba
- automatic version update by autodist

* Fri Jul 01 2022 Automatic Build System <autodist@mambasoft.it> 8.5.0-1mamba
- automatic version update by autodist

* Thu Jun 02 2022 Automatic Build System <autodist@mambasoft.it> 8.4.0-1mamba
- automatic version update by autodist

* Tue May 03 2022 Automatic Build System <autodist@mambasoft.it> 8.3.0-1mamba
- automatic version update by autodist

* Fri Apr 01 2022 Automatic Build System <autodist@mambasoft.it> 8.2.0-1mamba
- automatic version update by autodist

* Fri Mar 04 2022 Automatic Build System <autodist@mambasoft.it> 8.1.0-1mamba
- automatic version update by autodist

* Sat Jan 22 2022 Automatic Build System <autodist@mambasoft.it> 8.0.0-1mamba
- automatic version update by autodist

* Wed Dec 01 2021 Automatic Build System <autodist@mambasoft.it> 7.10.0-1mamba
- automatic version update by autodist

* Mon Nov 01 2021 Automatic Build System <autodist@mambasoft.it> 7.9.0-1mamba
- automatic version update by autodist

* Fri Oct 01 2021 Automatic Build System <autodist@mambasoft.it> 7.8.0-1mamba
- automatic version update by autodist

* Wed Sep 01 2021 Automatic Build System <autodist@mambasoft.it> 7.7.0-1mamba
- automatic version update by autodist

* Sun Aug 15 2021 Automatic Build System <autodist@mambasoft.it> 7.6.0-1mamba
- automatic version update by autodist

* Sun Jul 04 2021 Automatic Build System <autodist@mambasoft.it> 7.5.0-1mamba
- automatic version update by autodist

* Thu Jun 10 2021 Automatic Build System <autodist@mambasoft.it> 7.4.0-1mamba
- automatic version update by autodist

* Tue May 04 2021 Automatic Build System <autodist@mambasoft.it> 7.3.0-1mamba
- automatic version update by autodist

* Thu Apr 01 2021 Automatic Build System <autodist@mambasoft.it> 7.2.0-1mamba
- automatic version update by autodist

* Tue Mar 02 2021 Automatic Build System <autodist@mambasoft.it> 7.1.0-1mamba
- automatic version update by autodist

* Tue Jan 19 2021 Silvan Calarco <silvan.calarco@mambasoft.it> 7.0.0-2mamba
- rebuilt with wireshark 3.4.2

* Fri Jan 15 2021 Automatic Build System <autodist@mambasoft.it> 7.0.0-1mamba
- automatic version update by autodist

* Tue Dec 01 2020 Automatic Build System <autodist@mambasoft.it> 6.10.0-1mamba
- automatic version update by autodist

* Tue Nov 10 2020 Automatic Build System <autodist@mambasoft.it> 6.9.0-1mamba
- automatic version update by autodist

* Fri Oct 23 2020 Silvan Calarco <silvan.calarco@mambasoft.it> 6.8.0-1mamba
- update to 6.8.0

* Wed Feb 07 2018 Automatic Build System <autodist@mambasoft.it> 4.0.0-1mamba
- automatic version update by autodist

* Thu Dec 21 2017 Automatic Build System <autodist@mambasoft.it> 3.10.0-1mamba
- automatic version update by autodist

* Fri Nov 03 2017 Automatic Build System <autodist@mambasoft.it> 3.9.0-1mamba
- automatic version update by autodist

* Thu Oct 05 2017 Automatic Build System <autodist@mambasoft.it> 3.8.0-1mamba
- automatic version update by autodist

* Tue Sep 05 2017 Automatic Build System <autodist@mambasoft.it> 3.7.0-1mamba
- automatic version update by autodist

* Tue Aug 08 2017 Automatic Build System <autodist@mambasoft.it> 3.6.0-1mamba
- automatic version update by autodist

* Tue Apr 04 2017 Automatic Build System <autodist@mambasoft.it> 3.2.0-1mamba
- automatic version update by autodist

* Tue Mar 14 2017 Automatic Build System <autodist@mambasoft.it> 3.1.0-1mamba
- automatic version update by autodist

* Tue Jan 24 2017 Automatic Build System <autodist@mambasoft.it> 3.0.0-1mamba
- automatic version update by autodist

* Sat Dec 10 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.0-3mamba
- rebuilt by autoport with build requirements: libxen-devel>=4.8.0-1mamba

* Thu Nov 17 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 2.4.0-2mamba
- don't replace networks/default.xml and networks/autostart/default.xml

* Wed Nov 02 2016 Automatic Build System <autodist@mambasoft.it> 2.4.0-1mamba
- automatic version update by autodist

* Wed Oct 05 2016 Automatic Build System <autodist@mambasoft.it> 2.3.0-1mamba
- automatic version update by autodist

* Fri Sep 02 2016 Automatic Build System <autodist@mambasoft.it> 2.2.0-1mamba
- automatic version update by autodist

* Tue Aug 02 2016 Automatic Build System <autodist@mambasoft.it> 2.1.0-1mamba
- automatic version update by autodist

* Thu Jul 21 2016 Silvan Calarco <silvan.calarco@mambasoft.it> 2.0.0-1mamba
- update to 2.0.0

* Fri May 06 2016 Automatic Build System <autodist@mambasoft.it> 1.3.4-1mamba
- automatic version update by autodist

* Wed Apr 06 2016 Automatic Build System <autodist@mambasoft.it> 1.3.3-1mamba
- automatic version update by autodist

* Tue Mar 01 2016 Automatic Build System <autodist@mambasoft.it> 1.3.2-1mamba
- automatic version update by autodist

* Sun Jan 17 2016 Automatic Build System <autodist@mambasoft.it> 1.3.1-1mamba
- automatic version update by autodist

* Fri Dec 11 2015 Automatic Build System <autodist@mambasoft.it> 1.3.0-1mamba
- automatic version update by autodist

* Tue Nov 24 2015 Automatic Build System <autodist@mambasoft.it> 1.2.21-1mamba
- automatic version update by autodist

* Sun Apr 05 2015 Automatic Build System <autodist@mambasoft.it> 1.2.14-1mamba
- automatic version update by autodist

* Tue Jan 27 2015 Automatic Build System <autodist@mambasoft.it> 1.2.12-1mamba
- automatic version update by autodist

* Sat Dec 13 2014 Automatic Build System <autodist@mambasoft.it> 1.2.11-1mamba
- automatic version update by autodist

* Thu Dec 11 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.10-2mamba
- provide polkit localauthority file to allow remote connection to sysadmin group
- require netcat-openbsd for remote connection

* Mon Nov 03 2014 Automatic Build System <autodist@mambasoft.it> 1.2.10-1mamba
- automatic version update by autodist

* Wed Oct 01 2014 Automatic Build System <autodist@mambasoft.it> 1.2.9-1mamba
- automatic version update by autodist

* Fri Sep 05 2014 Automatic Build System <autodist@mambasoft.it> 1.2.8-1mamba
- automatic version update by autodist

* Sun Aug 03 2014 Automatic Build System <autodist@mambasoft.it> 1.2.7-1mamba
- automatic version update by autodist

* Sat Jul 05 2014 Automatic Build System <autodist@mambasoft.it> 1.2.6-1mamba
- automatic version update by autodist

* Thu Jun 05 2014 Automatic Build System <autodist@mambasoft.it> 1.2.5-1mamba
- automatic version update by autodist

* Sun May 04 2014 Automatic Build System <autodist@mambasoft.it> 1.2.4-1mamba
- automatic version update by autodist

* Sat May 03 2014 Silvan Calarco <silvan.calarco@mambasoft.it> 1.2.3-2mamba
- rebuild with systemd support
- require dnsmasq and ebtables

* Tue Apr 01 2014 Automatic Build System <autodist@mambasoft.it> 1.2.3-1mamba
- automatic version update by autodist

* Mon Mar 03 2014 Automatic Build System <autodist@mambasoft.it> 1.2.2-1mamba
- automatic version update by autodist

* Thu Jan 16 2014 Automatic Build System <autodist@mambasoft.it> 1.2.1-1mamba
- automatic version update by autodist

* Sat Dec 07 2013 Automatic Build System <autodist@mambasoft.it> 1.2.0-1mamba
- automatic version update by autodist

* Mon Nov 04 2013 Automatic Build System <autodist@mambasoft.it> 1.1.4-1mamba
- automatic version update by autodist

* Tue Oct 01 2013 Automatic Build System <autodist@mambasoft.it> 1.1.3-1mamba
- automatic version update by autodist

* Wed Sep 04 2013 Automatic Build System <autodist@mambasoft.it> 1.1.2-1mamba
- automatic version update by autodist

* Tue Jul 30 2013 Automatic Build System <autodist@mambasoft.it> 1.1.1-1mamba
- automatic version update by autodist

* Tue Jul 02 2013 Automatic Build System <autodist@mambasoft.it> 1.1.0-1mamba
- automatic version update by autodist

* Wed Jun 05 2013 Automatic Build System <autodist@mambasoft.it> 1.0.6-1mamba
- automatic version update by autodist

* Thu May 30 2013 Automatic Build System <autodist@mambasoft.it> 1.0.5-1mamba
- automatic version update by autodist

* Mon Sep 24 2012 Automatic Build System <autodist@mambasoft.it> 0.10.2-1mamba
- automatic version update by autodist

* Fri Aug 31 2012 Automatic Build System <autodist@mambasoft.it> 0.10.1-1mamba
- automatic version update by autodist

* Wed Aug 29 2012 Automatic Build System <autodist@mambasoft.it> 0.10.0-1mamba
- automatic version update by autodist

* Tue Jul 31 2012 Automatic Build System <autodist@mambasoft.it> 0.9.13-1mamba
- automatic version update by autodist

* Sat Jan 07 2012 Automatic Build System <autodist@mambasoft.it> 0.9.9-1mamba
- automatic version update by autodist

* Thu Dec 08 2011 Automatic Build System <autodist@mambasoft.it> 0.9.8-1mamba
- automatic version update by autodist

* Tue Nov 15 2011 Automatic Build System <autodist@mambasoft.it> 0.9.7-1mamba
- automatic version update by autodist

* Sat Oct 01 2011 Automatic Build System <autodist@mambasoft.it> 0.9.6-1mamba
- automatic version update by autodist

* Wed Aug 03 2011 Automatic Build System <autodist@mambasoft.it> 0.9.4-1mamba
- automatic version update by autodist

* Mon Jul 04 2011 Automatic Build System <autodist@mambasoft.it> 0.9.3-1mamba
- automatic update by autodist

* Sun Jun 19 2011 Automatic Build System <autodist@mambasoft.it> 0.9.2-1mamba
- automatic update by autodist

* Thu May 12 2011 Automatic Build System <autodist@mambasoft.it> 0.9.1-1mamba
- automatic update by autodist

* Mon Jan 31 2011 Automatic Build System <autodist@mambasoft.it> 0.8.7-1mamba
- automatic update by autodist

* Wed Dec 01 2010 Automatic Build System <autodist@mambasoft.it> 0.8.6-1mamba
- automatic update by autodist

* Wed Sep 29 2010 Automatic Build System <autodist@mambasoft.it> 0.8.4-1mamba
- automatic update by autodist

* Tue Jun 22 2010 Silvan Calarco <silvan.calarco@mambasoft.it> 0.8.1-1mamba
- update to 0.8.1
- rebuilt with Xen support

* Fri May 28 2010 Davide Madrisan <davide.madrisan@gmail.com> 0.7.7-2mamba
- add required directories in %{_localstatedir}/log/libvirt

* Sun Mar 21 2010 Davide Madrisan <davide.madrisan@gmail.com> 0.7.7-1mamba
- update to 0.7.7

* Mon Sep 14 2009 Davide Madrisan <davide.madrisan@gmail.com> 0.7.0-1mamba
- package created by autospec
